/*
 * mvs-tmdb-movie.h
 *
 * This file is part of maevies
 * Copyright (C) 2010 Simón Pena <spenap@gmail.com>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 */

#ifndef _MVS_TMDB_MOVIE
#define _MVS_TMDB_MOVIE

#include <glib-object.h>

G_BEGIN_DECLS

#define MVS_TYPE_TMDB_MOVIE mvs_tmdb_movie_get_type()
#define MVS_TMDB_MOVIE(obj) \
  (G_TYPE_CHECK_INSTANCE_CAST ((obj), MVS_TYPE_TMDB_MOVIE, MvsTmdbMovie))
#define MVS_TMDB_MOVIE_CLASS(klass) \
  (G_TYPE_CHECK_CLASS_CAST ((klass), MVS_TYPE_TMDB_MOVIE, MvsTmdbMovieClass))
#define MVS_IS_TMDB_MOVIE(obj) \
  (G_TYPE_CHECK_INSTANCE_TYPE ((obj), MVS_TYPE_TMDB_MOVIE))
#define MVS_IS_TMDB_MOVIE_CLASS(klass) \
  (G_TYPE_CHECK_CLASS_TYPE ((klass), MVS_TYPE_TMDB_MOVIE))
#define MVS_TMDB_MOVIE_GET_CLASS(obj) \
  (G_TYPE_INSTANCE_GET_CLASS ((obj), MVS_TYPE_TMDB_MOVIE, MvsTmdbMovieClass))

typedef struct _MvsTmdbMoviePrivate MvsTmdbMoviePrivate;

typedef struct {
        GObject parent;

        /* <private> */
        MvsTmdbMoviePrivate *priv;
} MvsTmdbMovie;

typedef struct {
        GObjectClass parent_class;
} MvsTmdbMovieClass;

GType mvs_tmdb_movie_get_type (void);
MvsTmdbMovie* mvs_tmdb_movie_new (void);

gboolean
mvs_tmdb_movie_set_alt_name (MvsTmdbMovie *self, const gchar *alt_name);

const gchar*
mvs_tmdb_movie_get_alt_name (MvsTmdbMovie *self);

gboolean
mvs_tmdb_movie_set_certification (MvsTmdbMovie *self, const gchar *certification);

const gchar*
mvs_tmdb_movie_get_certification (MvsTmdbMovie *self);

gboolean
mvs_tmdb_movie_set_id (MvsTmdbMovie *self, const gchar *id);

const gchar*
mvs_tmdb_movie_get_id (MvsTmdbMovie *self);

gboolean
mvs_tmdb_movie_set_images (MvsTmdbMovie *self, const gchar *images);

const gchar*
mvs_tmdb_movie_get_images (MvsTmdbMovie *self);

gboolean
mvs_tmdb_movie_set_imdb_id (MvsTmdbMovie *self, const gchar *imdb_id);

const gchar*
mvs_tmdb_movie_get_imdb_id (MvsTmdbMovie *self);

gboolean
mvs_tmdb_movie_set_language (MvsTmdbMovie *self, const gchar *language);

const gchar*
mvs_tmdb_movie_get_language (MvsTmdbMovie *self);

gboolean
mvs_tmdb_movie_set_last_modified (MvsTmdbMovie *self,
                                  const gchar *last_modified);

const gchar*
mvs_tmdb_movie_get_last_modified (MvsTmdbMovie *self);

gboolean
mvs_tmdb_movie_set_name (MvsTmdbMovie *self, const gchar *names);

const gchar*
mvs_tmdb_movie_get_name (MvsTmdbMovie *self);

gboolean
mvs_tmdb_movie_set_overview (MvsTmdbMovie *self, const gchar *overview);

const gchar*
mvs_tmdb_movie_get_overview (MvsTmdbMovie *self);

gboolean
mvs_tmdb_movie_set_popularity (MvsTmdbMovie *self, const gchar *popularity);

gboolean
mvs_tmdb_movie_set_rating (MvsTmdbMovie *self, const gchar *rating);

const gchar*
mvs_tmdb_movie_get_rating (MvsTmdbMovie *self);

gboolean
mvs_tmdb_movie_set_released (MvsTmdbMovie *self, const gchar *released);

const gchar*
mvs_tmdb_movie_get_released (MvsTmdbMovie *self);

gboolean
mvs_tmdb_movie_set_score (MvsTmdbMovie *self, const gchar *score);

const gchar*
mvs_tmdb_movie_get_score (MvsTmdbMovie *self);

gboolean
mvs_tmdb_movie_set_translated (MvsTmdbMovie *self, const gchar *translated);

const gchar*
mvs_tmdb_movie_get_translated (MvsTmdbMovie *self);

gboolean
mvs_tmdb_movie_set_type (MvsTmdbMovie *self, const gchar *type);

const gchar*
mvs_tmdb_movie_get_source_type (MvsTmdbMovie *self);

gboolean
mvs_tmdb_movie_set_url (MvsTmdbMovie *self, const gchar *url);

const gchar*
mvs_tmdb_movie_get_url (MvsTmdbMovie *self);

void
mvs_tmdb_movie_print (MvsTmdbMovie *self);

G_END_DECLS

#endif /* _MVS_TMDB_MOVIE */
